# Example Package

This is a simple convolution package, which enables me to explore some of the features with PyPi - thanks by the way.

You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.
